//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Mask/MaskGraphicsProxy.cpp
//! @brief     Implements class MaskGraphicsProxy
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Mask/MaskGraphicsProxy.h"
#include "GUI/Model/Data/Data2DItem.h"
#include "GUI/View/ProShape/MaskType.h"
#include <QGraphicsSceneMouseEvent>

MaskGraphicsProxy::MaskGraphicsProxy()
    : m_send_signals_to_colormap(false)
{
    resize(1200, 1000);
    setInZoomMode(true);
}

MaskGraphicsProxy::~MaskGraphicsProxy() = default;

int MaskGraphicsProxy::type() const
{
    return MaskType::MASKGRAPHICSPROXY;
}

//! Sets widget to zoom mode, when signals (zoom wheel, mouse clicks) are send down to
//! ColorMap plot. In non-zoom mode, widget doesn't react on clicks.
void MaskGraphicsProxy::setInZoomMode(bool value)
{
    m_send_signals_to_colormap = value;
    if (value)
        setAcceptedMouseButtons(Qt::LeftButton);
    else
        setAcceptedMouseButtons(Qt::NoButton);
}

void MaskGraphicsProxy::mousePressEvent(QGraphicsSceneMouseEvent* event)
{
    if (!m_send_signals_to_colormap)
        return;
    QGraphicsProxyWidget::mousePressEvent(event);
    event->accept();
}

void MaskGraphicsProxy::mouseReleaseEvent(QGraphicsSceneMouseEvent* event)
{
    if (!m_send_signals_to_colormap)
        return;
    QGraphicsProxyWidget::mouseReleaseEvent(event);
}

void MaskGraphicsProxy::wheelEvent(QGraphicsSceneWheelEvent* event)
{
    if (!m_send_signals_to_colormap)
        return;
    QGraphicsProxyWidget::wheelEvent(event);
}

void MaskGraphicsProxy::mouseMoveEvent(QGraphicsSceneMouseEvent* event)
{
    if (!m_send_signals_to_colormap)
        return;
    QGraphicsProxyWidget::mouseMoveEvent(event);
}
