//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Shape/MaskContainerDisplay.cpp
//! @brief     Implements MaskContainerDisplay class
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Shape/MaskContainerDisplay.h"
#include "GUI/Model/Data/ProjectionItems.h"
#include "GUI/Model/Mask/MaskItems.h"
#include "GUI/View/ProShape/SceneAdaptor.h"
#include <QBrush>
#include <QPainter>
#include <QStyleOptionGraphicsItem>

MaskContainerDisplay::MaskContainerDisplay(MaskContainerItem* item)
    : IShapeDisplay(item)
    , m_item(item)
{
    // the key flag to not to draw children going outside ot given shape
    setFlag(QGraphicsItem::ItemClipsChildrenToShape, true);
}

MaskContainerDisplay::MaskContainerDisplay(ProjectionContainerItem* item)
    : IShapeDisplay(item)
    , m_item(item)
{
    setFlag(QGraphicsItem::ItemClipsChildrenToShape, true);
}

MaskRoot* MaskContainerDisplay::parameterizedItem() const
{
    return m_item;
}

void MaskContainerDisplay::update_view()
{
    m_bounding_rect = m_adaptor->viewportRectangle();
    update();
}

void MaskContainerDisplay::paint(QPainter* painter, const QStyleOptionGraphicsItem*, QWidget*)
{
    Q_UNUSED(painter);
}
